/*
 * Copyright (C) 2000 John David Ratliff, 
 *                    Christopher Michael O'Donnel, and
 *                    Hongwei Guan
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

package tools;

import tools.Document;

import java.util.Iterator;
import java.util.NoSuchElementException;

public class DocumentIterator implements Iterator {
	private Document document;
	private int documentSize, iteration, stopAtLine;

	// The constructor for an iterator that returns ALL the lines
	// in the document from 0 to (size - 1)
	public DocumentIterator(Document document) {
		this(document, 0, document.getLineCount());
	}

	// The constructor that iterates between 'start' and 'end'
	public DocumentIterator(Document document, int start, int end) {
		this.document = document;
		this.documentSize = document.getLineCount();
		this.iteration = start;
		this.stopAtLine = end;
	}

	// if there are more lines in the DocumentIterator, return true, else false
	public boolean hasNext() {
		if (this.iteration >= this.documentSize || this.iteration > this.stopAtLine) {
			return false;
		}

		return true;
	}

	// returns the next line in the Document (it would return String, except
	// that java.util.Iterator specifies an Object)
	public Object next() throws NoSuchElementException {
		Object element;

		if (!this.hasNext()) {
			// throw a NoSuchElementException if we don't have
			// a next Element

			throw new NoSuchElementException("End of Document Exception");
		}

		element = this.document.getLine(this.iteration);
		this.iteration++;

		return element;
	}

	public void remove() throws UnsupportedOperationException {
		// java.util.Iterator specifies this method, but also has a clause
		// in the documentation for UnsupportedOperationExceptions on this
		// method -- this method has no meaning for DocumentIterator

		throw new UnsupportedOperationException("DocumentIterator does not support the remove() method.");
	}
}
